@@ -1,14 +1,14 @@
-from creevey.ops.image import centercrop
 import numpy as np
 from PIL import Image
 import torch.nn as nn
+from wildebeest.ops.image import centercrop
 
 
 def center_crop_pil_image(img):
     """
     Helper function to crop the center out of images.
 
-    Utilizes the centercrop function from `creevey`
+    Utilizes the centercrop function from `wildebeest`
 
     Parameters
     ----------
